@@ -1,5 +1,6 @@
 import numpy as np  # noqa: E402
 import pandas as pd  # noqa: E402
+import pytest
 import xarray as xr  # noqa: E402
 
 from make_test_files import make_local_netcdf
@@ -18,6 +19,18 @@ make_local_netcdf()
 fname = "test_local.nc"
 fullname = f"tests/{fname}"
 
+my_custom_criteria = {
+    "temp": {"name": "(?i)temperature$"},
+}
+
+var_def = {
+    "temp": {
+        "units": "degree_Celsius",
+        "fail_span": [-100, 100],
+        "suspect_span": [-10, 40],
+    },
+}
+
 
 def test_units():
     ds = xr.Dataset()
@@ -36,9 +49,28 @@ def test_qc():
 
     filenames = fullname
     data = odg.Gateway(
-        approach="stations", readers=odg.local, local={"filenames": filenames}
+        approach="stations",
+        readers=odg.local,
+        local={"filenames": filenames},
+        criteria=my_custom_criteria,
+        var_def=var_def,
     )
     data.dataset_ids
     assert isinstance(data.meta, pd.DataFrame)
     data[fname]
     assert (data.qc()[fname]["temperature_qc"] == np.ones(10)).all()
+
+
+def test_qc_error():
+    """Running QC without config or units should draw error."""
+
+    filenames = fullname
+    data = odg.Gateway(
+        approach="stations", readers=odg.local, local={"filenames": filenames}
+    )
+    data.dataset_ids
+    assert isinstance(data.meta, pd.DataFrame)
+    data[fname]
+
+    with pytest.raises(AssertionError):
+        assert (data.qc()[fname]["temperature_qc"] == np.ones(10)).all()
